package main

import (
	"flag"
	"fmt"

	"dag-jupyter/internal/config"
	"dag-jupyter/internal/handler"
	"dag-jupyter/internal/svc"

	"github.com/zeromicro/go-zero/core/conf"
	"github.com/zeromicro/go-zero/core/logx"
	"github.com/zeromicro/go-zero/rest"
)

var configFile = flag.String("f", "etc/jupyter-api.yaml", "the config file")

func main() {
	flag.Parse()

	var c config.Config
	var lc logx.LogConf
	conf.MustLoad(*configFile, &c)
	conf.MustLoad(*configFile, &lc)
	logx.MustSetup(lc)
	defer logx.Close()
	server := rest.MustNewServer(c.RestConf)
	defer server.Stop()

	ctx := svc.NewServiceContext(c)
	handler.RegisterHandlers(server, ctx)

	fmt.Printf("Starting server at %s:%d...\n", c.Host, c.Port)
	server.Start()
}
